\name{STGP}
\alias{STGP}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Fit the scalar-on-image models via STGP.
}
\description{
This function fits the scalar-on-image regression model via soft-thresholded Gaussian process, running the Markov chain Monte Carlo algorithm.
}
\usage{
STGP(Y, X, B, ADJ, t_min, t_max, binary = FALSE, Xp = NULL, 
    ae = 0.1, be = 0.1, ar = 10, br = 1, eps = c(0.1, 10), 
    iters = 5000, burn = 1000, thin = 2,show_iters=5)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{Y}{
n x 1 vector of normalized responses.
}
  \item{X}{
n x p matrix of normalized covariates.
}
  \item{B}{
p x m matrix of kernel basis functions.
}
  \item{ADJ}{
m x m adjacency matrix for the kernel knots.
}
  \item{t_min, t_max}{
prior for the threshold is Unif(t_min,t_max).
}

  \item{binary}{
\code{logical}; whether the response is binary?
}
  \item{Xp}{
n_pred x p matrix of covariates for test set prediction.
}
  \item{ae, be}{
If Y is Gaussian its variance has InvG(ae,be) prior.
}
  \item{ar, br}{
CAR dependence parameter has a beta(ar,br) prior.
}
  \item{eps}{
beta[j]'s prior variance is 1/eps[j].
}
  \item{iters}{
number of MCMC iterations.
}
  \item{burn}{
number if discard as burn-in.
}
  \item{thin}{
thinning intervals
}
\item{show_iters}{
iterations to show
}
}
\details{
We assume that the beta to be estimated is a Gaussian process with zero-mean and some stationary covariance function. Furthermore, beta has a soft-thresholded Gaussian process prior, where the thresholding parameter determines the degree of sparsity. 

For the scalar-on-image regression model, in practice, we normalize the response and covariates, and then select priors: 
\deqn{\alpha^v~N(0,10^2I_q), \sigma^2~InvGamma(0.1,0.1), \sigma_a~HalfNormal(0,1), \vartheta~Beta(10,1) and \lambda~Uniform(\lambda_l,\lambda_u).
}

We fit our model running the proposed Markov chain Monte Carlo algorithm \code{iters} iterations with \code{burn} burn-in, and computer the posterior mean and variance of beta. For the sparse model, we compute the posterior probability of a nonzero beta.

For more details, see \code{References}.
}
\value{
\item{beta.mn}{
Posterio mean of beta[2]*b.
}
\item{beta.var}{
Posterior variance of beta[2]*b.
}
\item{beta.nz}{
Posterior probability beta[2]*b is non-zero.
}
\item{fit.mn}{
Posterior mean of test set Y.
}
\item{fit.var}{
Posterior variance of test set Y.
}
\item{keepers}{
Posterior draws for other parameters.
}
\item{LogLike}{
Posterior log-likelihood of the model.
}
}
\references{
Jian Kang, Brian J. Reich and Ana-Maria Staicu. (2016) Scalar-on-Image Regression via the Soft-Thresholded Gaussian Process, working paper.
}
\author{
Jian Kang(jiankang@umich.edu), 
Brain J. Reich (bjreich@ncsu.edu), Ana-Maria Staicu (astaicu@ncsu.edu), Weiyu Li (weiyuli@umich.edu)
}
\note{
%%  ~~further notes~~
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
}
\examples{
## Simulation
sim1 <- sim.STGP(100,500,25,r=c(0.1,0.5))

## Fit
fit1 <- STGP(sim1$Y,sim1$X,sim1$B,sim1$ADJ,t_min=0,t_max=3)

## plots
par(mfrow=c(2,2))
plot(sim1$voxel,sim1$beta,type="l",ylab="beta",main="True beta")
plot(sim1$voxel,fit1$beta.mn,type="l",ylab="Mean",main="E(beta|data)")
plot(sim1$voxel,fit1$beta.var,type="l",ylab="Variance",main="Var(beta|data)")
plot(sim1$voxel,fit1$beta.nz,type="l",ylab="Probability",main="Prob(beta!=0|data)")

## Binary data
Y2   <- ifelse(sim1$Y>0,1,0)
fit2 <- STGP(Y2,sim1$X,sim1$B,sim1$ADJ,t_min=0,t_max=3,binary=TRUE)
}

\keyword{fit}
