\name{sim.STGP}
\alias{sim.STGP}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Simulation of the independent scalar-on-image regression model.
}
\description{
This function generate a stochastic simulation of the independent scalar-on-image regression model.
}
\usage{
sim.STGP(n, p, m, dim = 1, r = c(0.1, 0.5))
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{n}{
\code{numeric}; The number of observations. 
}
  \item{p}{
\code{numeric}; The number of voxels of imaging predictors in \code{[0,1]} on each axis.
}
  \item{m}{
\code{numeric}; The number of knots in \code{[0,1]} on each axis.
}
  \item{dim}{
\code{numeric}; The dimension of voxels.
}
  \item{r}{
\code{numeric} or \code{numeric vector}; The radius of the simulated true beta image. For \code{dim=1}, it denotes the interval where \code{beta=1}.
}
}
\details{
Here we only simulate a simple independent case of scalar-on-image regression model. The true beta we simulate are distributed as: beta equals to 1 in a selected range, and 0 otherwise.
}
\value{
A list containing a simulation of scalar-on-image model which includes:
\item{Y}{
A vector containing a scalar response variable.
}
\item{X}{
A matrix containing a covariates of spatially distributed imaging predictors.
}
\item{beta}{
A vector containing the simulated true beta.
}
\item{B}{
The kernel basis functions matrix.
}
\item{ADJ}{
The adjacency matrix for the kernel knots.
}
\item{voxel}{
The locations of the voxels.
}
}
\references{
Jian Kang, Brian J. Reich and Ana-Maria Staicu. (2016) Scalar-on-Image Regression via the Soft-Thresholded Gaussian Process, working paper
}
\author{
Weiyu Li (weiyuli@umich.edu), Jian Kang(jiankang@umich.edu), 
Brain J. Reich (bjreich@ncsu.edu), Ana-Maria Staicu (astaicu@ncsu.edu)
}
\note{
%%  ~~further notes~~
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
}
\examples{
## One-dimesional
sim1 <- sim.STGP(100,500,25,r=c(0.1,0.5))

## Two-dimesional with p^2=50^2 predictors and m^2=10^2 knots 
sim2 <- sim.STGP(100,50,10,dim=2,r=1/4)
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{simulation}
\keyword{model}% __ONLY ONE__ keyword per line
