#include <Rcpp.h>
#include <math.h>

using namespace Rcpp;

// [[Rcpp::export]]

NumericMatrix GaussInverse(NumericMatrix x){
  int n = x.nrow();
  
  int i, j, k;
  double max, temp;
  
  // put x in a temp matrix t
  NumericMatrix t(n,n);
  for (i = 0; i<n; i++){
    for (j=0; j<n; j++){t(i, j) = x(i, j);}
  }
  
  // initialize y as identity matrix
  NumericMatrix y(n,n);
  for (i=0; i<n; i++){
    for (j=0; j<n; j++){y(i,j) = (i == j) ? (float)1 : 0;}
  }
  
  // find the elementary row
  for (i=0; i<n; i++){
    max = t(i,i);
    k = i;
    for (j=i+1; j<n; j++){
      if (fabs(t(j,i)) > fabs(max)){
        max = t(j,i);
        k = j;
      }
    }
    
    // swap if the elementary row is not row i
    if (k != i){
      for (j=0; j<n; j++){
        temp = t(i, j);
        t(i, j) = t(k, j);
        t(k, j) = temp;
        
        // swap y
        temp = y(i, j);
        y(i, j) = y(k, j);
        y(k, j) = temp;
      }
    }
    
    // elementary cannot be 0
    if (t(i, i) == 0){Rcout << "Singular Matrix!";}
    
    // eliminate column i except (i,i)
    temp = t(i, i);
    for (j=0; j<n; j++){
      t(i, j) = t(i, j) / temp;
      y(i, j) = y(i, j) / temp;
    } 
    
    for (j=0; j<n; j++){
      if (j != i){
        temp = t(j,i);
        for (k=0; k<n; k++){
          t(j,k) = t(j,k) - t(i,k) * temp;
          y(j,k) = y(j,k) - y(i,k) * temp;
        }
      }
    }
  }
  
  return y;
}
