#include <Rcpp.h>
#include <cmath>

using namespace Rcpp;

// [[Rcpp::export]]

List fastLM(NumericVector y, NumericVector x){
  NumericVector ymn = y - mean(y);
  NumericVector xmn = x - mean(x);
  int n = y.size();
  double s2y = sum(ymn * ymn );
  s2y /= n - 1.0;
  double s2x = sum(xmn * xmn );
  s2x /= n - 1.0;
  double sxy = sum( xmn * ymn );
  sxy /= n - 1.0;
  double rxy = sxy;
  rxy /= sqrt( s2y * s2x );
  double b = rxy * sqrt( s2y / s2x);
  double se_b = sqrt(s2y * ( 1.0 - rxy * rxy) / (n - 2.0) / s2x);
  NumericVector tstat;
  tstat.push_back(rxy * sqrt( ( n - 2 ) / ( 1 - rxy * rxy ) ));
  NumericVector p = pt(abs(tstat), n - 2 ,0, 0)*2;
  return Rcpp::List::create(
    Rcpp::Named("beta") = b,
    Rcpp::Named("se.beta") = se_b,
    Rcpp::Named("t.stat") = tstat[0], 
                                 Rcpp::Named("p.value") = p[0]); 
}
